summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/ViewShellBase.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/ViewShellBase.hxx')
-rwxr-xr-xsd/source/ui/inc/ViewShellBase.hxx22
1 files changed, 11 insertions, 11 deletions
diff --git a/sd/source/ui/inc/ViewShellBase.hxx b/sd/source/ui/inc/ViewShellBase.hxx
index 38f7223f1d83..cd89d85249bd 100755
--- a/sd/source/ui/inc/ViewShellBase.hxx
+++ b/sd/source/ui/inc/ViewShellBase.hxx
@@ -136,12 +136,12 @@ public:
virtual com::sun::star::uno::Reference<com::sun::star::view::XRenderable> GetRenderable (void);
/// Forwarded to the print manager.
- virtual SfxPrinter* GetPrinter (BOOL bCreate = FALSE);
+ virtual SfxPrinter* GetPrinter (sal_Bool bCreate = sal_False);
/// Forwarded to the print manager.
- virtual USHORT SetPrinter (
+ virtual sal_uInt16 SetPrinter (
SfxPrinter* pNewPrinter,
- USHORT nDiffFlags = SFX_PRINTER_ALL, bool bIsApi=false);
+ sal_uInt16 nDiffFlags = SFX_PRINTER_ALL, bool bIsApi=false);
/// Forwarded to the print manager.
virtual PrintDialog* CreatePrintDialog (::Window *pParent);
@@ -152,13 +152,13 @@ public:
const SfxItemSet &rOptions);
/// Forwarded to the print manager.
- virtual USHORT Print (SfxProgress& rProgress, BOOL bIsAPI, PrintDialog* pDialog);
+ virtual sal_uInt16 Print (SfxProgress& rProgress, sal_Bool bIsAPI, PrintDialog* pDialog);
/// Forwarded to the print manager.
virtual ErrCode DoPrint (
SfxPrinter *pPrinter,
PrintDialog *pPrintDialog,
- BOOL bSilent, BOOL bIsAPI );
+ sal_Bool bSilent, sal_Bool bIsAPI );
virtual void PreparePrint (PrintDialog* pPrintDialog);
@@ -179,18 +179,18 @@ public:
virtual void UIActivating( SfxInPlaceClient* );
virtual void UIDeactivated( SfxInPlaceClient* );
- virtual void Activate (BOOL IsMDIActivate);
- virtual void Deactivate (BOOL IsMDIActivate);
+ virtual void Activate (sal_Bool IsMDIActivate);
+ virtual void Deactivate (sal_Bool IsMDIActivate);
virtual void SetZoomFactor (
const Fraction &rZoomX,
const Fraction &rZoomY);
- virtual USHORT PrepareClose (BOOL bUI = TRUE, BOOL bForBrowsing = FALSE);
- virtual void WriteUserData (String&, BOOL bBrowse = FALSE);
- virtual void ReadUserData (const String&, BOOL bBrowse = FALSE);
+ virtual sal_uInt16 PrepareClose (sal_Bool bUI = sal_True, sal_Bool bForBrowsing = sal_False);
+ virtual void WriteUserData (String&, sal_Bool bBrowse = sal_False);
+ virtual void ReadUserData (const String&, sal_Bool bBrowse = sal_False);
virtual SdrView* GetDrawView (void) const;
virtual void AdjustPosSizePixel (const Point &rOfs, const Size &rSize);
/** When <TRUE/> is given, then the mouse shape is set to hour glass (or
whatever the busy shape looks like on the system.)
*/
void SetBusyState (bool bBusy);
@@ -179,18 +179,18 @@ public:
virtual SdrView* GetDrawView (void) const;
virtual void AdjustPosSizePixel (const Point &rOfs, const Size &rSize);
- /** When <TRUE/> is given, then the mouse shape is set to hour glass (or
+ /** When <sal_True/> is given, then the mouse shape is set to hour glass (or
whatever the busy shape looks like on the system.)
*/